package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.BusinessCoupon;

/**
 * 优惠卷Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-25
 */
public interface BusinessCouponMapper 
{
    /**
     * 查询优惠卷
     * 
     * @param couponId 优惠卷主键
     * @return 优惠卷
     */
    public BusinessCoupon selectBusinessCouponByCouponId(Long couponId);

    /**
     * 查询优惠卷列表
     * 
     * @param businessCoupon 优惠卷
     * @return 优惠卷集合
     */
    public List<BusinessCoupon> selectBusinessCouponList(BusinessCoupon businessCoupon);

    /**
     * 新增优惠卷
     * 
     * @param businessCoupon 优惠卷
     * @return 结果
     */
    public int insertBusinessCoupon(BusinessCoupon businessCoupon);

    /**
     * 修改优惠卷
     * 
     * @param businessCoupon 优惠卷
     * @return 结果
     */
    public int updateBusinessCoupon(BusinessCoupon businessCoupon);

    /**
     * 删除优惠卷
     * 
     * @param couponId 优惠卷主键
     * @return 结果
     */
    public int deleteBusinessCouponByCouponId(Long couponId);

    /**
     * 批量删除优惠卷
     * 
     * @param couponIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusinessCouponByCouponIds(Long[] couponIds);
}
