package com.ruoyi.mall.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.BusinessCoupon;
import com.ruoyi.mall.service.IBusinessCouponService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 优惠卷Controller
 * 
 * @author ruoyi
 * @date 2023-10-25
 */
@RestController
@RequestMapping("/mall/coupon")
public class BusinessCouponController extends BaseController
{
    @Autowired
    private IBusinessCouponService businessCouponService;

    /**
     * 查询优惠卷列表
     */
    @PreAuthorize("@ss.hasPermi('mall:coupon:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusinessCoupon businessCoupon)
    {
        startPage();
        List<BusinessCoupon> list = businessCouponService.selectBusinessCouponList(businessCoupon);
        return getDataTable(list);
    }

    /**
     * 导出优惠卷列表
     */
    @PreAuthorize("@ss.hasPermi('mall:coupon:export')")
    @Log(title = "优惠卷", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusinessCoupon businessCoupon)
    {
        List<BusinessCoupon> list = businessCouponService.selectBusinessCouponList(businessCoupon);
        ExcelUtil<BusinessCoupon> util = new ExcelUtil<BusinessCoupon>(BusinessCoupon.class);
        util.exportExcel(response, list, "优惠卷数据");
    }

    /**
     * 获取优惠卷详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:coupon:query')")
    @GetMapping(value = "/{couponId}")
    public AjaxResult getInfo(@PathVariable("couponId") Long couponId)
    {
        return AjaxResult.success(businessCouponService.selectBusinessCouponByCouponId(couponId));
    }

    /**
     * 新增优惠卷
     */
    @PreAuthorize("@ss.hasPermi('mall:coupon:add')")
    @Log(title = "优惠卷", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusinessCoupon businessCoupon)
    {
        return toAjax(businessCouponService.insertBusinessCoupon(businessCoupon));
    }

    /**
     * 修改优惠卷
     */
    @PreAuthorize("@ss.hasPermi('mall:coupon:edit')")
    @Log(title = "优惠卷", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusinessCoupon businessCoupon)
    {
        return toAjax(businessCouponService.updateBusinessCoupon(businessCoupon));
    }

    /**
     * 删除优惠卷
     */
    @PreAuthorize("@ss.hasPermi('mall:coupon:remove')")
    @Log(title = "优惠卷", businessType = BusinessType.DELETE)
	@DeleteMapping("/{couponIds}")
    public AjaxResult remove(@PathVariable Long[] couponIds)
    {
        return toAjax(businessCouponService.deleteBusinessCouponByCouponIds(couponIds));
    }
}
